Effect

Struct Effect 

pub struct Effect<T, F>
where T: 'static, F: Fn(Option<T>) -> T,
{ /* private fields */ }
Handle for a running effect. Construct effects with Effect::new.

Implementations



impl<T, F> Effect<T, F>
where T: Any + 'static, F: Fn(Option<T>) -> T + 'static,

pub fn new(f: F)



impl Effect<(), fn(Option<()>)>

Create an effect updater that runs on_change when any signals within compute subscribe to changes. compute is immediately run and its return value is returned from UpdaterEffect::new_stateful. Signals that are wrapped with untrack will not subscribe to any effect.

pub fn untrack<T>(f: impl FnOnce() -> T) -> T

pub fn batch<T>(f: impl FnOnce() -> T) -> T