pub struct ImageRequest {
pub name: String,
pub path: String,
pub policy: ImageRetentionPolicy,
}Expand description
Request to load an image resource.
Fields
name: StringName used to reference the loaded image in styles and image views.
path: StringPath or URL to the image resource.
policy: ImageRetentionPolicyHow long the image should be retained in memory.