Memo

Struct Memo 

pub struct Memo<T>
where T: PartialEq + 'static,
{ /* private fields */ }
A memoized derived value that only recomputes when one of its tracked dependencies changes, and only notifies dependents when its value changes.

Unlike the previous implementation, this is driven by dependency invalidation rather than an Effect that eagerly recomputes.

Implementations



impl<T> Memo<T>
where T: PartialEq + 'static,

Create a Memo which takes the computed value of the given function, and triggers the reactive system when the computed value is different from the last computed value.

pub fn new(f: impl Fn(Option<&T>) -> T + 'static) -> Memo<T>