pub struct ProgressBar;Expand description
A simple progress bar that can be used to show the progress of something.
The input lens need to be a lens to an f32 with range of 0.0..1.0.
Example
Vertical ProgressBar bound to the input lens
ProgressBar::vertical(cx, AppData::progress);Horizontal ProgressBar bound to the input lens
ProgressBar::horizontal(cx, AppData::progress);A Horizontal ProgressBar with a label beside it to show the progress
HStack::new(cx, |cx| {
ProgressBar::horizontal(cx, AppData::progress);
Label::new(cx, AppData::progress.map(|v| format!("{:.0}%", v * 100.0)));
});Implementations
Sourceimpl ProgressBar
impl ProgressBar
Sourcepub fn new<L>(
cx: &mut Context,
lens: L,
orientation: Orientation,
) -> Handle<'_, ProgressBar>
pub fn new<L>( cx: &mut Context, lens: L, orientation: Orientation, ) -> Handle<'_, ProgressBar>
Creates a new progress bar bound to the value targeted by the lens.
Example
ProgressBar::new(cx, AppData::value, Orientation::Horizontal);Sourcepub fn horizontal<L>(cx: &mut Context, lens: L) -> Handle<'_, ProgressBar>
pub fn horizontal<L>(cx: &mut Context, lens: L) -> Handle<'_, ProgressBar>
Creates a new horizontal progress bar bound to the value targeted by the lens.