Table

Struct Table 

pub struct Table<T, V, Id, K = String>
where V: Deref<Target = [T]> + Clone + 'static, T: PartialEq + Clone + 'static, Id: PartialEq + Clone + 'static, K: Clone + PartialEq + Send + Sync + 'static,
{ /* private fields */ }
A table-like view backed by List for variable row heights.

This implementation prioritizes flexible row layout over viewport virtualization. For large datasets, prefer filtering, pagination, or incremental loading at the model layer.

Implementations

Source

impl<T, V, Id, K> Table<T, V, Id, K>
where V: Deref<Target = [T]> + Clone + 'static, T: PartialEq + Clone + 'static, Id: PartialEq + Clone + 'static, K: Clone + PartialEq + Send + Sync + 'static,

pub fn new<S, C, R, H>( cx: &mut Context, rows: S, columns: C, row_id: impl Fn(&T) -> Id + 'static, ) -> Handle<'_, Table<T, V, Id, K>>
where S: Res<V> + 'static, C: Res<R> + 'static, R: Deref<Target = [TableColumn<T, H, K>]> + Clone + 'static, H: Clone + View,

Creates a new table view.

Sorting is emit-only: header presses call on_sort, while sorted data should be provided by the caller (for example via Memo<Vec<T>>).

Table::new(cx, sorted_rows, columns, |row: &RowData| row.id)
    .sort_state(sort_state)
    .resizable_columns(true)
    .selectable(Selectable::Single)
    .selected_row_ids(selected_ids)
    .on_sort(|cx, column, direction| {
        cx.emit(AppEvent::SetSort(column, direction));
    })
    .on_row_select(|cx, id| {
        cx.emit(AppEvent::SelectRow(id));
    });