Struct UpdaterEffect
pub struct UpdaterEffect<T, I, C, U> { /* private fields */ }Expand description
Internal updater effect handle. Prefer the associated constructors over the free functions.
Implementations
impl UpdaterEffect<(), (), (), ()>
Create an effect updater that runs on_change when any signals that subscribe during the
run of compute are updated. compute is immediately run only once, and its value is returned
from UpdaterEffect::new.
impl UpdaterEffect<(), (), (), ()>
Create an effect updater that runs on_change when any signals that subscribe during the
run of compute are updated. compute is immediately run only once, and its value is returned
from UpdaterEffect::new.
pub fn new<R>(
compute: impl Fn() -> R + 'static,
on_change: impl Fn(R) + 'static,
) -> Rwhere
R: 'static,
pub fn new<R>(
compute: impl Fn() -> R + 'static,
on_change: impl Fn(R) + 'static,
) -> Rwhere
R: 'static,
Create an effect updater that runs on_change when any signals that subscribe during the
run of compute are updated. compute is immediately run only once, and its value is returned
from UpdaterEffect::new.
pub fn new_stateful<T, R>(
compute: impl Fn(Option<T>) -> (R, T) + 'static,
on_change: impl Fn(R, T) -> T + 'static,
) -> Rwhere
T: Any + 'static,
R: 'static,
pub fn new_stateful<T, R>(
compute: impl Fn(Option<T>) -> (R, T) + 'static,
on_change: impl Fn(R, T) -> T + 'static,
) -> Rwhere
T: Any + 'static,
R: 'static,
Create an effect updater that runs on_change when any signals within compute subscribe to
changes. compute is immediately run and its return value is returned.