Struct Memo
pub struct Memo<T>where
T: PartialEq + 'static,{ /* private fields */ }Expand description
A memoized derived value that only recomputes when one of its tracked dependencies changes, and only notifies dependents when its value changes.
Unlike the previous implementation, this is driven by dependency invalidation
rather than an Effect that eagerly recomputes.
Implementations