pub struct Resizable { /* private fields */ }Expand description
A view that can be resized by clicking and dragging from one of its edges.
The Resizable struct allows users to create a resizable container in a user interface.
It supports resizing in either a horizontal or vertical direction, as specified
by the direction field. The resizing behavior is controlled via the on_drag callback, which
is triggered during a drag operation.
Implementations
Sourceimpl Resizable
impl Resizable
Sourcepub fn new<F>(
cx: &mut Context,
size: impl Res<Units> + Copy + 'static,
direction: ResizeStackDirection,
on_drag: impl Fn(&mut EventContext<'_>, f32) + 'static,
content: F,
) -> Handle<'_, Resizable>
pub fn new<F>( cx: &mut Context, size: impl Res<Units> + Copy + 'static, direction: ResizeStackDirection, on_drag: impl Fn(&mut EventContext<'_>, f32) + 'static, content: F, ) -> Handle<'_, Resizable>
Creates a new Resizable view.
The size parameter is a Res<Units> source for the stack size, updated when the stack is resized.
The direction parameter specifies which edge of the stack is resizable.
The on_drag callback is called with the new size when the stack is being resized.
The content closure is called to build the content of the stack.